Garfield.data.GraphAnnTorchDataset
==================================

.. currentmodule:: Garfield.data

.. autoclass:: GraphAnnTorchDataset

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GraphAnnTorchDataset.__init__
   
   

   
   
   